@@ -52,6 +52,8 @@ class Booking(enum.Enum):
     # Last-in first-out in the case of ambiguity.
     LIFO = 'LIFO'
 
+    # Highest-in first-out in the case of ambiguity.
+    HIFO = 'HIFO'
 
 def new_directive(clsname, fields: List[Tuple]) -> NamedTuple:
     """Create a directive class. Do not include default fields.
@@ -613,6 +615,7 @@ def posting_sortkey(entry):
     return (entry.date, SORT_ORDER.get(type(entry), 0), entry.meta["lineno"])
 
 
+# TODO(blais): Rename 'txns' to 'transactions' for clarity.
 def filter_txns(entries):
     """A generator that yields only the Transaction instances.
 
