@@ -2,6 +2,7 @@ __copyright__ = "Copyright (C) 2014-2016  Martin Blais"
 __license__ = "GNU GPLv2"
 
 import datetime
+import unittest
 
 from beancount.core.amount import A
 from beancount.core import inventory
@@ -45,6 +46,8 @@ class TestPadding(cmptest.TestCase):
 
         """, entries)
 
+        self.assertTrue(all(isinstance(p.meta, dict) for p in entries[3].postings))
+
     @loader.load_doc()
     def test_pad_to_zero(self, entries, errors, __):
         """
@@ -568,3 +571,7 @@ class TestPadding(cmptest.TestCase):
         # self.assertEqual(1, len(errors))
         # self.assertRegex(errors[0].message, "Balance failed")
         # self.assertEqual(datetime.date(2015, 9, 15), errors[0].entry.date)
+
+
+if __name__ == '__main__':
+    unittest.main()
