@@ -226,7 +226,7 @@ class TestLexer(unittest.TestCase):
             ('EOL', 2, b'\n', None),
         ], tokens)
         self.assertTrue(errors)
-        self.assertRegex(errors[0].message, '(out of range|month must be)')
+        self.assertRegex(errors[0].message, 'out of range|month must be|day must be in')
 
     @lex_tokens
     def test_date_followed_by_number(self, tokens, errors):
@@ -298,14 +298,14 @@ class TestLexer(unittest.TestCase):
           ;; This is a typical error that should get detected for long strings.
           2014-01-01 note Assets:Temporary "Bla bla" "
           2014-02-01 open Liabilities:US:BankWithLongName:Credit-Card:Account01
-        """ + "\n" * 64 + """
+        """ + "\n" * 2048 + """
           2014-02-02 note Assets:Temporary "Bla bla"
         """
         builder = lexer.LexBuilder()
         tokens = list(lexer.lex_iter_string(textwrap.dedent(test_input), builder))
         self.assertLessEqual(1, len(builder.errors))
-        self.assertEqual(builder.errors[0].message,
-                         'ValueError: String too long (68 lines)')
+        self.assertRegex(builder.errors[0].message,
+                         'ValueError: String too long (.* lines)')
 
     def test_very_long_string(self):
         # This tests lexing with a string of 256k.
