@@ -74,6 +74,7 @@ def align_position_strings(strings):
     fmt_unknown = "{{:<{0}}}".format(max_total).format
 
     # Align the strings and return them.
+    # pylint: disable=format-string-without-interpolation
     aligned_strings = []
     for index, string in string_items:
         if index is not None:
@@ -136,7 +137,9 @@ class EntryPrinter:
             return
         if prefix is None:
             prefix = self.prefix
-        for key, value in sorted(meta.items()):
+        # Note: meta.items() is assumed stable from 3.7 onwards; we're not sorting
+        # on purpose in order to keep the original insertion order in print.
+        for key, value in meta.items():
             if key not in self.META_IGNORE:
                 value_str = None
                 if isinstance(value, str):
@@ -194,7 +197,7 @@ class EntryPrinter:
             width_account = self.min_width_account
 
         non_trivial_balance = (any(map(interpolate.has_nontrivial_balance, entry.postings))
-                               if self.render_weight
+                               if self.render_weight and width_weight > 0
                                else False)
         if non_trivial_balance:
             fmt = "{0}{{:{1}}}  {{:{2}}}  ; {{:{3}}}\n".format(
@@ -203,9 +206,10 @@ class EntryPrinter:
                                                                   strs_account,
                                                                   strs_position,
                                                                   strs_weight):
+                # pylint: disable=format-string-without-interpolation
                 oss.write(fmt(account,
                               position_str,
-                              weight_str if non_trivial_balance else ''))
+                              weight_str or ''))
                 if posting.meta:
                     self.write_metadata(posting.meta, oss, '    ')
         else:
@@ -215,6 +219,7 @@ class EntryPrinter:
             for posting, account, position_str in zip(entry.postings,
                                                       strs_account,
                                                       strs_position):
+                # pylint: disable=format-string-without-interpolation
                 print(fmt(account, position_str).rstrip(), file=oss)
                 if posting.meta:
                     self.write_metadata(posting.meta, oss, '    ')
