@@ -292,7 +292,7 @@ class Subst(query_compile.EvalFunction):
 
     def __call__(self, context):
         args = self.eval_args(context)
-        if any([arg is None for arg in args]):
+        if any(arg is None for arg in args):
             return None
         return re.sub(args[0], args[1], args[2])
 
@@ -305,7 +305,7 @@ class Upper(query_compile.EvalFunction):
 
     def __call__(self, context):
         args = self.eval_args(context)
-        if any([arg is None for arg in args]):
+        if any(arg is None for arg in args):
             return None
         return args[0].upper()
 
@@ -318,7 +318,7 @@ class Lower(query_compile.EvalFunction):
 
     def __call__(self, context):
         args = self.eval_args(context)
-        if any([arg is None for arg in args]):
+        if any(arg is None for arg in args):
             return None
         return args[0].lower()
 
@@ -355,7 +355,7 @@ class Meta(query_compile.EvalFunction):
 
     def __call__(self, context):
         args = self.eval_args(context)
-        meta = context.posting.meta
+        meta = context.posting.meta if context.posting else None
         if meta is None:
             return None
         return meta.get(args[0], None)
