@@ -49,8 +49,7 @@ def find_repository_root(filename=None):
     if match:
         return match.group(1)
 
-    while not all(path.exists(path.join(filename, sigfile))
-                  for sigfile in ('PKG-INFO', 'COPYING', 'README.rst')):
+    while not path.exists(path.join(filename, 'setup.py')):
         prev_filename = filename
         filename = path.dirname(filename)
         if prev_filename == filename:
@@ -235,7 +234,7 @@ def docfile(function, **kwargs):
     @functools.wraps(function)
     def new_function(self):
         allowed = ('buffering', 'encoding', 'newline', 'dir', 'prefix', 'suffix')
-        if any([key not in allowed for key in kwargs]):
+        if any(key not in allowed for key in kwargs):
             raise ValueError("Invalid kwarg to docfile_extra")
         with tempfile.NamedTemporaryFile('w', **kwargs) as file:
             text = contents or function.__doc__
