@@ -13,7 +13,7 @@ from . import acme_pdf
 IMPORTER = acme_pdf.Importer("Assets:US:AcmeBank")
 
 @pytest.mark.skipif(not acme_pdf.is_pdfminer_installed(),
-                    reason="PDFMiner2 is not installed")
+                    reason="pdfminer2 is not installed")
 @regtest.with_importer(IMPORTER)
 @regtest.with_testdir(path.dirname(__file__))
 class TestImporter(regtest.ImporterTestBase):
